@@ -24,7 +24,9 @@
 
 #include <glib.h>
 
-gboolean	dnf_validate_supported_source(const gchar*);
+G_BEGIN_DECLS
+
+gboolean	dnf_validate_supported_repo (const gchar *id);
 
 G_END_DECLS
 
