@@ -22,14 +22,8 @@
 #ifndef __PACKAGEKIT_H__
 #define __PACKAGEKIT_H__
 
-#ifndef I_KNOW_THE_PACKAGEKIT_GLIB2_API_IS_SUBJECT_TO_CHANGE
-#error You have to define I_KNOW_THE_PACKAGEKIT_GLIB2_API_IS_SUBJECT_TO_CHANGE
-#endif
-
 #define __PACKAGEKIT_H_INSIDE__
 
-#include <packagekit-glib2/pk-catalog.h>
-#include <packagekit-glib2/pk-category.h>
 #include <packagekit-glib2/pk-category.h>
 #include <packagekit-glib2/pk-client.h>
 #include <packagekit-glib2/pk-client-sync.h>
@@ -45,8 +39,8 @@
 #include <packagekit-glib2/pk-eula-required.h>
 #include <packagekit-glib2/pk-files.h>
 #include <packagekit-glib2/pk-media-change-required.h>
-#include <packagekit-glib2/pk-message.h>
 #include <packagekit-glib2/pk-item-progress.h>
+#include <packagekit-glib2/pk-offline.h>
 #include <packagekit-glib2/pk-package-id.h>
 #include <packagekit-glib2/pk-package-ids.h>
 #include <packagekit-glib2/pk-package-sack.h>
@@ -56,7 +50,6 @@
 #include <packagekit-glib2/pk-repo-signature-required.h>
 #include <packagekit-glib2/pk-require-restart.h>
 #include <packagekit-glib2/pk-results.h>
-#include <packagekit-glib2/pk-service-pack.h>
 #include <packagekit-glib2/pk-task.h>
 #include <packagekit-glib2/pk-task-sync.h>
 #include <packagekit-glib2/pk-transaction-past.h>
