@@ -101,7 +101,7 @@ pk_client_helper_child_free (PkClientHelperChild *child)
 		g_source_unref (child->socket_channel_source);
 	}
 	if (child->pid > 0)
-		kill (child->pid, SIGQUIT);
+		kill (child->pid, SIGTERM);
 	if (child->stdin_channel != NULL)
 		g_io_channel_unref (child->stdin_channel);
 	if (child->stdout_channel != NULL)
@@ -154,8 +154,8 @@ pk_client_helper_stop (PkClientHelper *client_helper, GError **error)
 		PkClientHelperChild *child = g_ptr_array_index (priv->children, i);
 		int retval;
 
-		g_debug ("sending SIGQUIT %ld", (long)child->pid);
-		retval = kill (child->pid, SIGQUIT);
+		g_debug ("sending SIGTERM %ld", (long)child->pid);
+		retval = kill (child->pid, SIGTERM);
 		if (retval == EINVAL) {
 			g_set_error (error, 1, 0, "failed to kill, signum argument is invalid");
 			return FALSE;
@@ -415,11 +415,11 @@ pk_client_helper_start (PkClientHelper *client_helper,
 			gchar **argv, gchar **envp,
 			GError **error)
 {
-	guint i;
 	gboolean use_kde_helper = FALSE;
 	PkClientHelperPrivate *priv = GET_PRIVATE(client_helper);
 	g_autoptr(GError) error_local = NULL;
 	g_autoptr(GSocketAddress) address = NULL;
+	const gchar *kde_helper_path = "/usr/libexec/debconf-kde-helper";
 
 	g_return_val_if_fail (PK_IS_CLIENT_HELPER (client_helper), FALSE);
 	g_return_val_if_fail (socket_filename != NULL, FALSE);
@@ -442,12 +442,18 @@ pk_client_helper_start (PkClientHelper *client_helper,
 
 	/* preconfigure KDE frontend, if requested */
 	if (envp != NULL) {
-		for (i = 0; envp[i] != NULL; i++) {
+		for (guint i = 0; envp[i] != NULL; i++) {
 			if (g_strcmp0 (envp[i], "DEBIAN_FRONTEND=kde") == 0) {
-				if (g_file_test ("/usr/bin/debconf-kde-helper",
-						 G_FILE_TEST_EXISTS)) {
+				if (g_file_test (kde_helper_path, G_FILE_TEST_EXISTS)) {
 					use_kde_helper = TRUE;
+				} else {
+					/* try alternative path */
+					kde_helper_path = "/usr/bin/debconf-kde-helper";
+					if (g_file_test (kde_helper_path, G_FILE_TEST_EXISTS))
+						use_kde_helper = TRUE;
 				}
+
+				break;
 			}
 		}
 	}
@@ -464,13 +470,21 @@ pk_client_helper_start (PkClientHelper *client_helper,
 
 	/* spawn KDE debconf communicator */
 	if (use_kde_helper) {
+		g_debug ("Using KDE debconf communicator: %s", kde_helper_path);
+
 		priv->envp = g_strdupv (envp);
 		priv->argv = g_new0 (gchar *, 2);
-		priv->argv[0] = g_strdup ("/usr/bin/debconf-kde-helper");
+		priv->argv[0] = g_strdup (kde_helper_path);
 		priv->argv[1] = g_strconcat ("--socket-path", "=", socket_filename, NULL);
 
-		if (!g_spawn_async (NULL, priv->argv, NULL, G_SPAWN_STDOUT_TO_DEV_NULL,
-			NULL, NULL, &priv->kde_helper_pid, &error_local)) {
+		if (!g_spawn_async (NULL,
+				    priv->argv,
+				    priv->envp,
+				    G_SPAWN_STDOUT_TO_DEV_NULL,
+				    NULL,
+				    NULL,
+				    &priv->kde_helper_pid,
+				    &error_local)) {
 			g_warning ("failed to spawn: %s", error_local->message);
 			return FALSE;
 		}
@@ -609,7 +623,7 @@ pk_client_helper_finalize (GObject *object)
 	g_clear_pointer (&priv->socket_channel, g_io_channel_unref);
 	g_clear_pointer (&priv->children, g_ptr_array_unref);
 	if (priv->kde_helper_pid > 0)
-		kill (priv->kde_helper_pid, SIGQUIT);
+		kill (priv->kde_helper_pid, SIGTERM);
 
 	G_OBJECT_CLASS (pk_client_helper_parent_class)->finalize (object);
 }
